==> qmmp_1.4.3.orig.tar.bz2: qmmp-1.4.3/src/plugins/Input/cue/translations/cue_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="38"/>
        <source>CUE Plugin</source>
        <translation>Suplemento CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="41"/>
        <source>CUE Files</source>
        <translation>Ficheiros CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="85"/>
        <source>About CUE Audio Plugin</source>
        <translation>Sobre o suplemento CUE Audio</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="86"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Suplemento Qmmp CUE Audio</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="87"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Definições gerais</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation>Se possível, carregar ficheiros CUE incorretos</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>Codificação CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Deteção automática de caracteres</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Codificação padrão:</translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Input/cue/translations/cue_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="38"/>
        <source>CUE Plugin</source>
        <translation>Suplemento CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="41"/>
        <source>CUE Files</source>
        <translation>Ficheiros CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="84"/>
        <source>About CUE Audio Plugin</source>
        <translation>Acerca de suplemento CUE Audio</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="85"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Suplemento Qmmp CUE Audio</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="86"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Desenvolvido por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Definições gerais</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation>Se possível, carregar ficheiros CUE incorretos</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>Codificação CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Deteção automática de caracteres</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Codificação padrão:</translation>
    </message>
</context>
</TS>
